@@ -185,6 +185,12 @@ cal_backend_kolab_signal_online_cb (GObject *object)
 	 *
 	 */
 
+	if (priv->cal_koma == NULL) {
+		g_warning ("%s()[%u] Backend not yet opened, ignoring online state request",
+		           __func__, __LINE__);
+		return;
+	}
+
 	(void) kolab_util_backend_deploy_mode_by_backend (priv->cal_koma,
 	                                                  online,
 	                                                  NULL, /* GCancellable (see above ) */
@@ -264,19 +270,15 @@ cal_backend_kolab_open (ECalBackendSync *backend,
 {
 	ECalBackendKolab *self = NULL;
 	ECalBackendKolabPrivate *priv = NULL;
-	ESource *esource = NULL;
-	ESourceKolabFolder *extension = NULL;
 	CamelKolabIMAPXSettings *kolab_settings = NULL;
 	CamelNetworkSettings *network_settings = NULL;
 	KolabSettingsHandler *ksettings = NULL;
-	KolabSyncStrategyID sync_value = KOLAB_SYNC_STRATEGY_DEFAULT;
 	icalcomponent_kind icalkind = ICAL_VEVENT_COMPONENT;
-	const gchar *extension_name = NULL;
-	const gchar *foldername = NULL;
 	const gchar *cache_dir = NULL;
 	gchar *cache_filename = NULL;
 	gchar *servername = NULL;
 	gchar *username = NULL;
+	const gchar *user_home = NULL;
 	gboolean online = FALSE;
 	gboolean ok = FALSE;
 	GError *tmp_err = NULL;
@@ -310,13 +312,6 @@ cal_backend_kolab_open (ECalBackendSync *backend,
 		goto exit;
 	}
 
-	esource = e_backend_get_source (E_BACKEND (backend));
-	if (! E_IS_SOURCE (esource)) {
-		tmp_err = e_data_cal_create_error (OtherError,
-		                                   _("Could not get ESource for backend"));
-		goto exit;
-	}
-
 	kolab_settings = cal_backend_kolab_get_collection_settings (self);
 	network_settings = CAMEL_NETWORK_SETTINGS (kolab_settings);
 
@@ -325,16 +320,23 @@ cal_backend_kolab_open (ECalBackendSync *backend,
 	g_debug ("%s()[%u] servername = %s", __func__, __LINE__, servername);
 	g_debug ("%s()[%u]   username = %s", __func__, __LINE__, username);
 
-	/* TODO this is sort of hackish, we cannot be sure that
-	 *      'user@server' is truly the Kolab email address
-	 *      of the Kolab user
-	 */
-	priv->user_email = g_strdup_printf ("%s@%s", username, servername);
+	priv->user_email = kolab_util_calendar_dup_email_address (E_CAL_BACKEND (backend));
+	if (priv->user_email == NULL) {
+		/* fallback if getting mail address from
+		 * ESource failed - synthesized one is just
+		 * guessing!
+		 */
+		if (g_str_has_suffix (username, servername))
+			priv->user_email = g_strdup (username);
+		else
+			priv->user_email = g_strdup_printf ("%s@%s", username, servername);
+		g_warning ("%s()[%u] Could not get email address from ESource, synthesized '%s'",
+		           __func__, __LINE__, priv->user_email);
+	}
 
 	/* Initialize backend cache */
-	if (priv->cal_cache != NULL) {
+	if (priv->cal_cache != NULL)
 		g_object_unref (priv->cal_cache);
-	}
 
 	cache_dir = e_cal_backend_get_cache_dir (E_CAL_BACKEND (backend));
 	cache_filename = g_build_filename (cache_dir, "cache.xml", NULL);
@@ -344,16 +346,11 @@ cal_backend_kolab_open (ECalBackendSync *backend,
 	ok = e_file_cache_clean (E_FILE_CACHE (priv->cal_cache));
 	g_debug (" + Cal cache cleaning %s.", ok ? "was successful" : "FAILED");
 
-	/* Prepare data from sync strategy property */
-	extension_name = E_SOURCE_EXTENSION_KOLAB_FOLDER;
-	extension = e_source_get_extension (esource, extension_name);
-	sync_value = e_source_kolab_folder_get_sync_strategy (extension);
-
 	online = e_backend_get_online (E_BACKEND (backend));
-	foldername = kolab_util_backend_get_foldername (E_BACKEND (backend));
 
 	/* Configure settings handler */
-	ksettings = kolab_settings_handler_new (kolab_settings);
+	ksettings = kolab_settings_handler_new (kolab_settings,
+	                                        E_BACKEND (backend));
 	ok = kolab_settings_handler_configure (ksettings,
 	                                       KOLAB_FOLDER_CONTEXT_CALENDAR,
 	                                       &tmp_err);
@@ -364,18 +361,19 @@ cal_backend_kolab_open (ECalBackendSync *backend,
 	if (! ok)
 		goto exit;
 
-	kolab_util_backend_prepare_settings (ksettings,
-	                                     esource,
-	                                     NULL,
-	                                     foldername,
-	                                     &sync_value);
+	/* init the HTTP utils */
+	user_home = kolab_settings_handler_get_char_field (ksettings,
+	                                                   KOLAB_SETTINGS_HANDLER_CHAR_FIELD_USER_HOME_DIR,
+	                                                   &tmp_err);
+	if (tmp_err != NULL)
+		goto exit;
+	kolab_util_http_init (user_home);
 
 	/* create new KolabMailAccess instance */
 	priv->cal_koma = KOLAB_MAIL_ACCESS (g_object_new (KOLAB_TYPE_MAIL_ACCESS, NULL));
 
 	/* configure and bring up KolabMailAccess instance */
 	ok = kolab_mail_access_configure (priv->cal_koma,
-	                                  E_BACKEND (backend),
 	                                  ksettings,
 	                                  &tmp_err);
 	if (! ok)
@@ -510,7 +508,6 @@ cal_backend_kolab_get_backend_property (ECalBackendSync *backend,
 		                        CAL_STATIC_CAPABILITY_REMOVE_ALARMS ","
 		                        CAL_STATIC_CAPABILITY_NO_THISANDFUTURE ","
 		                        CAL_STATIC_CAPABILITY_NO_THISANDPRIOR ","
-		                        CAL_STATIC_CAPABILITY_CREATE_MESSAGES ","
 		                        CAL_STATIC_CAPABILITY_NO_CONV_TO_ASSIGN_TASK ","
 		                        CAL_STATIC_CAPABILITY_NO_CONV_TO_RECUR ","
 		                        CAL_STATIC_CAPABILITY_HAS_UNACCEPTED_MEETING ","
@@ -714,7 +711,7 @@ cal_backend_kolab_get_free_busy (ECalBackendSync *backend,
 	ECalBackendKolabPrivate *priv = NULL;
 	KolabSettingsHandler *ksettings = NULL;
 	GSList *it = NULL;
-	gboolean internal_state = TRUE;
+	gboolean have_objects = FALSE;
 	GError *tmp_err = NULL;
 
 	g_return_if_fail (error == NULL || *error == NULL);
@@ -733,54 +730,70 @@ cal_backend_kolab_get_free_busy (ECalBackendSync *backend,
 	if (ksettings == NULL) {
 		/* TODO add a translatable string as custom message */
 		tmp_err = e_data_cal_create_error (OtherError, NULL);
+		goto exit;
 	}
 
+	/* If we went through authentication already, we can make the
+	 * password visible via ksettings so it can be used in
+	 * KolabUtilHttpJob. If we're not authenticated, we're most
+	 * probably offline, in which case we cannot fetch XFB anyway
+	 */
+	kolab_mail_access_password_set_visible (priv->cal_koma, TRUE);
+
 	/* receive the xfb information */
 	for (it = (GSList *) users; it != NULL; it = g_slist_next (it)) {
 		KolabUtilHttpJob *job = NULL;
 		ECalComponent *ecalcomp = NULL;
 
-		job = kolab_util_calendar_retrieve_xfb (ksettings, (gchar *) it->data, &tmp_err);
-		if (job != NULL) {
-			ecalcomp = kolabconv_cal_util_freebusy_ecalcomp_new_from_ics ((gchar *) (job->buffer->data),
-			                                                              job->nbytes,
-			                                                              &tmp_err);
-			kolab_util_http_job_free (job);
-		}
-		if (tmp_err != NULL) {
-			/* TODO Can we sensibly propagate an error
-			 *      here? Failure for one does not
-			 *      necessarily imply failure for all
-			 */
-			g_warning ("%s()[%u] %s", __func__, __LINE__, tmp_err->message);
-			g_error_free (tmp_err);
-			tmp_err = NULL;
-			internal_state = FALSE;
-		}
+		/* TODO Can we sensibly propagate an error
+		 *      here? Failure for one does not
+		 *      necessarily imply failure for all
+		 */
 
-		if (ecalcomp == NULL) {
+		job = kolab_util_calendar_retrieve_xfb (ksettings, (gchar *) it->data, &tmp_err);
+		if (tmp_err != NULL)
+			goto skip_warn;
+
+		ecalcomp = kolabconv_cal_util_freebusy_ecalcomp_new_from_ics ((gchar *) (job->buffer->data),
+		                                                              job->nbytes,
+		                                                              &tmp_err);
+		kolab_util_http_job_free (job);
+
+		if (tmp_err != NULL)
+			goto skip_warn;
+
+		if (ecalcomp == NULL)
 			/* this is not an error, but there's no F/B
 			 * information available.
 			 */
-			g_object_unref (ksettings);
-			tmp_err = e_data_cal_create_error (ObjectNotFound, NULL);
-			g_propagate_error (error, tmp_err);
-			return;
-		}
-		else {
-			*freebusyobjs = g_slist_append (*freebusyobjs,
-			                                g_strdup (e_cal_component_get_as_string (ecalcomp)));
-			g_object_unref (ecalcomp);
-		}
+			continue;
+
+		*freebusyobjs = g_slist_append (*freebusyobjs,
+		                                g_strdup (e_cal_component_get_as_string (ecalcomp)));
+		g_object_unref (ecalcomp);
+		have_objects = TRUE;
+
+		continue;
+
+	skip_warn:
+		g_warning ("%s()[%u] %s", __func__, __LINE__, tmp_err->message);
+		g_error_free (tmp_err);
+		tmp_err = NULL;
 	}
-	g_object_unref (ksettings);
-	if (! internal_state) {
-		/* TODO add a translatable string as custom message here,
-		 *      could use a saved tmp_err->message (e.g. latest)
-		 */
-		tmp_err = e_data_cal_create_error (OtherError, NULL);
+
+ exit:
+
+	/* hide the password again */
+	kolab_mail_access_password_set_visible (priv->cal_koma, FALSE);
+
+	if (ksettings != NULL)
+		g_object_unref (ksettings);
+
+	if (! have_objects)
+		tmp_err = e_data_cal_create_error (ObjectNotFound, NULL);
+
+	if (tmp_err != NULL)
 		g_propagate_error (error, tmp_err);
-	}
 }
 
 /**
@@ -1308,7 +1321,7 @@ cal_backend_kolab_remove_objects (ECalBackendSync *backend,
 		oc_data = (*old_components)->data;
 	if (*new_components != NULL)
 		nc_data = (*new_components)->data;
-	
+
 	e_cal_backend_notify_component_removed (E_CAL_BACKEND (backend),
 	                                        id,
 	                                        oc_data,
@@ -1716,6 +1729,12 @@ cal_backend_kolab_start_view (ECalBackend *backend,
 
 	g_object_ref (view); /* unref()d in stop_view() */
 
+	if (priv->cal_koma == NULL) {
+		g_warning ("%s()[%u] Backend not been opened, not updating view",
+		           __func__, __LINE__);
+		goto exit;
+	}
+
 	query = e_data_cal_view_get_text (view);
 	foldername = kolab_util_backend_get_foldername (E_BACKEND (backend));
 
@@ -1879,7 +1898,7 @@ e_cal_backend_kolab_init (ECalBackendKolab *backend)
 
 	/* init subsystems (these are no-ops if already called before) */
 	kolab_util_glib_init ();
-	kolab_util_http_init ();
+
 	/* libcamel
 	 * Curl init may configure the underlying SSL lib,
 	 * but as far as SSL goes, we want Camel to rule here
