@@ -139,9 +139,9 @@ kolab_util_calendar_cache_get_tz (ECalBackendCache *cache,
 
 /**
  * kolab_util_calendar_cache_get_object:
+ * @backend: an #ECalBackendSync
  * @cal_cache: A Cache.
  * @koma: A KolabMailAccess object.
- * @uri: An ECalComponent uri string.
  * @uid: The uid to search for.
  * @bulk: Whether or not this is a mass operation.
  * @cancellable: A cancellation stack.
@@ -154,9 +154,9 @@ kolab_util_calendar_cache_get_tz (ECalBackendCache *cache,
  *          Unref if no longer needed.
  **/
 ECalComponent*
-kolab_util_calendar_cache_get_object (ECalBackendCache *cal_cache,
+kolab_util_calendar_cache_get_object (ECalBackendSync *backend,
+                                      ECalBackendCache *cal_cache,
                                       KolabMailAccess *koma,
-                                      const gchar *uri,
                                       const gchar *uid,
                                       gboolean bulk,
                                       GCancellable *cancellable,
@@ -166,25 +166,24 @@ kolab_util_calendar_cache_get_object (ECalBackendCache *cal_cache,
 	ECalComponent *comp = NULL;
 	ECalComponent *tz = NULL;
 	GError *tmp_error = NULL;
-	gchar *sourcename = NULL;
+	const gchar *foldername;
 	gchar *tzid = NULL;
 	gboolean ok = FALSE;
 
+	g_assert (E_IS_CAL_BACKEND_SYNC (backend));
 	g_assert (E_IS_CAL_BACKEND_CACHE (cal_cache));
 	g_assert (KOLAB_IS_MAIL_ACCESS (koma));
-	g_assert (uri != NULL);
 	g_assert (uid != NULL);
 	/* cancellable may be NULL */
 	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
 
-	sourcename = kolab_util_backend_get_relative_path_from_uri (uri);
+	foldername = kolab_util_backend_get_foldername (E_BACKEND (backend));
 
 	kmh = kolab_mail_access_get_handle (koma,
 	                                    uid,
-	                                    sourcename,
+	                                    foldername,
 	                                    cancellable,
 	                                    &tmp_error);
-	g_free (sourcename);
 	if (kmh == NULL) {
 		/* empty object, could be "nothing found" */
 		if (tmp_error != NULL) {
@@ -227,9 +226,9 @@ kolab_util_calendar_cache_get_object (ECalBackendCache *cal_cache,
 } /* kolab_util_calendar_cache_get_object () */
 
 gboolean
-kolab_util_calendar_cache_update_object (ECalBackendCache *cache,
+kolab_util_calendar_cache_update_object (ECalBackendSync *backend,
+                                         ECalBackendCache *cache,
                                          KolabMailAccess *koma,
-                                         const gchar *uri,
                                          const gchar *uid,
                                          gboolean bulk,
                                          GCancellable *cancellable,
@@ -237,16 +236,16 @@ kolab_util_calendar_cache_update_object (ECalBackendCache *cache,
 {
 	ECalComponent *ecalcomp = NULL;
 
+	g_assert (E_IS_CAL_BACKEND_SYNC (backend));
 	g_assert (E_IS_CAL_BACKEND_CACHE (cache));
 	g_assert (KOLAB_IS_MAIL_ACCESS (koma));
-	g_assert (uri != NULL);
 	g_assert (uid != NULL);
 	/* cancellable may be NULL */
 	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 
-	ecalcomp = kolab_util_calendar_cache_get_object (cache,
+	ecalcomp = kolab_util_calendar_cache_get_object (backend,
+	                                                 cache,
 	                                                 koma,
-	                                                 uri,
 	                                                 uid,
 	                                                 bulk,
 	                                                 cancellable,
@@ -312,40 +311,39 @@ kolab_util_calendar_cache_remove_instance (ECalBackendCache *cal_cache,
 } /* kolab_util_calendar_cache_remove_instance () */
 
 gboolean
-kolab_util_calendar_cache_update_on_query (ECalBackendCache *cache,
+kolab_util_calendar_cache_update_on_query (ECalBackendSync *backend,
+                                           ECalBackendCache *cache,
                                            KolabMailAccess *koma,
                                            const gchar *query,
-                                           const gchar *uri,
                                            GCancellable *cancellable,
                                            GError **error)
 {
 	GList *changed_uids = NULL;
-	gchar *sourcename = NULL;
+	const gchar *foldername;
 	GError *tmp_error = NULL;
 
 	g_debug ("%s()[%u] called.", __func__, __LINE__);
 
+	g_assert (E_IS_CAL_BACKEND_SYNC (backend));
 	g_assert (E_IS_CAL_BACKEND_CACHE (cache));
 	g_assert (KOLAB_IS_MAIL_ACCESS (koma));
 	/* query may be NULL */
-	g_assert (uri != NULL);
 	/* cancellable may be NULL */
 	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 
-	sourcename = kolab_util_backend_get_relative_path_from_uri (uri);
+	foldername = kolab_util_backend_get_foldername (E_BACKEND (backend));
 
 	/* Backend cache no longer in use for PIM objects -
 	 * we can just free() the result (but must fetch
 	 * it nonetheless)
 	 */
 	changed_uids = kolab_mail_access_query_changed_uids (koma,
-	                                                     sourcename,
+	                                                     foldername,
 	                                                     query,
 	                                                     cancellable,
 	                                                     &tmp_error);
 	if (tmp_error != NULL) {
 		g_propagate_error (error, tmp_error);
-		g_free (sourcename);
 		return FALSE;
 	}
 	if (changed_uids != NULL)
@@ -360,9 +358,9 @@ kolab_util_calendar_cache_update_on_query (ECalBackendCache *cache,
 
 /**
  * kolab_util_calendar_cache_assure_uid_on_ecalcomponent:
+ * @backend: an #ECalBackendSync
  * @cache: An ECalBackendCache.
  * @koma: A KolabMailAccess instance.
- * @uri: An ECalComponent uri string.
  * @ecalcomp: An ECalComponent.
  * @bulk: Whether or not this is a mass operation.
  * @cancellable: A cancellation stack.
@@ -373,10 +371,10 @@ kolab_util_calendar_cache_update_on_query (ECalBackendCache *cache,
  * Returns: On Success TRUE is returned.
  */
 gboolean
-kolab_util_calendar_cache_assure_uid_on_ecalcomponent (ECalBackendCache *cache,
+kolab_util_calendar_cache_assure_uid_on_ecalcomponent (ECalBackendSync *backend,
+                                                       ECalBackendCache *cache,
                                                        KolabMailAccess *koma,
                                                        ECalComponent *ecalcomp,
-                                                       const gchar *uri,
                                                        gboolean bulk,
                                                        GCancellable *cancellable,
                                                        GError **error)
@@ -387,10 +385,10 @@ kolab_util_calendar_cache_assure_uid_on_ecalcomponent (ECalBackendCache *cache,
 	gchar *uid = NULL;
 	KolabSettingsHandler *ksettings = NULL;
 
+	g_assert (E_IS_CAL_BACKEND_SYNC (backend));
 	g_assert (E_IS_CAL_BACKEND_CACHE (cache));
 	g_assert (KOLAB_IS_MAIL_ACCESS (koma));
 	g_assert (E_IS_CAL_COMPONENT (ecalcomp));
-	g_assert (uri != NULL);
 	/* cancellable may be NULL */
 	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 
@@ -406,9 +404,9 @@ kolab_util_calendar_cache_assure_uid_on_ecalcomponent (ECalBackendCache *cache,
 		uid = e_cal_component_gen_uid();
 	for (;;) {
 		/* remember, this has to be called with a non-empty uid */
-		tmp_comp = kolab_util_calendar_cache_get_object (cache,
+		tmp_comp = kolab_util_calendar_cache_get_object (backend,
+		                                                 cache,
 		                                                 koma,
-		                                                 uri,
 		                                                 uid,
 		                                                 bulk,
 		                                                 cancellable,
