@@ -37,6 +37,8 @@
 #include <libevolution-utils/e-alert.h>
 #include <misc/e-alert-bar.h>
 
+#include <libekolabutil/kolab-util-folder.h>
+
 #include <libekolab/camel-kolab-imapx-store.h>
 #include <libekolab/kolab-data-imap-account.h>
 #include <libekolab/kolab-util-backend.h>
@@ -116,6 +118,7 @@ struct _KolabFolderPropUIWidgets {
 typedef struct _KolabFolderPropUIData KolabFolderPropUIData;
 struct _KolabFolderPropUIData {
 	EShellView *shell_view;
+	KolabFolderContextID shell_context;
 	KolabFolderPropUIWidgets *widgets;
 	KolabFolderMetaUIData *meta_ui_data;
 	KolabFolderPermUIData *perm_ui_data;
@@ -143,11 +146,6 @@ kolab_folder_prop_ui_data_free (KolabFolderPropUIData *uidata)
 	if (uidata == NULL)
 		return;
 
-	/* FIXME do we need to ref/unref the shell view? */
-#if 0
-	g_object_unref (uidata->shell_view);
-#endif
-
 	/* the actual widgets will have been deleted already,
 	 * so just deleting the struct shell here
 	 */
@@ -284,12 +282,16 @@ static KolabFolderPropUIData*
 kolab_folder_prop_ui_dialog_data_new (EShellView *shell_view)
 {
 	KolabFolderPropUIData *uidata = NULL;
+	KolabFolderContextID context = KOLAB_FOLDER_CONTEXT_INVAL;
 	gchar *foldername = NULL;
 	gchar *sourcename = NULL;
 	GError *tmp_err = NULL;
 
 	g_return_val_if_fail (E_IS_SHELL_VIEW (shell_view), NULL);
 
+	context = e_kolab_plugin_util_ui_get_shell_context (shell_view);
+	g_return_val_if_fail (context != KOLAB_FOLDER_CONTEXT_INVAL, NULL);
+
 	foldername = e_kolab_plugin_util_ui_get_selected_foldername (shell_view,
 	                                                             &tmp_err);
 	if (tmp_err != NULL) {
@@ -311,6 +313,7 @@ kolab_folder_prop_ui_dialog_data_new (EShellView *shell_view)
 
 	uidata = kolab_folder_prop_ui_data_new ();
 	uidata->shell_view = shell_view; /* FIXME ref the view? */
+	uidata->shell_context = context;
 	uidata->widgets->alert_bar = e_alert_bar_new ();
 	uidata->widgets->notebook = gtk_notebook_new ();
 
@@ -329,6 +332,7 @@ kolab_folder_prop_ui_dialog_data_new (EShellView *shell_view)
 
 	uidata->meta_ui_data = e_kolab_folder_metadata_ui_new ();
 	uidata->meta_ui_data->shell_view = shell_view;
+	uidata->meta_ui_data->shell_context = context;
 	uidata->meta_ui_data->alert_bar = E_ALERT_BAR (uidata->widgets->alert_bar);
 	uidata->meta_ui_data->dialog = GTK_DIALOG (uidata->widgets->dialog);
 	uidata->meta_ui_data->foldername = g_strdup (foldername);
@@ -336,6 +340,7 @@ kolab_folder_prop_ui_dialog_data_new (EShellView *shell_view)
 
 	uidata->perm_ui_data = e_kolab_folder_permissions_ui_new ();
 	uidata->perm_ui_data->shell_view = shell_view;
+	uidata->perm_ui_data->shell_context = context;
 	uidata->perm_ui_data->alert_bar = E_ALERT_BAR (uidata->widgets->alert_bar);
 	uidata->perm_ui_data->dialog = GTK_DIALOG (uidata->widgets->dialog);
 	uidata->perm_ui_data->foldername = g_strdup (foldername);
@@ -350,6 +355,49 @@ kolab_folder_prop_ui_dialog_data_new (EShellView *shell_view)
 	return uidata;
 }
 
+static void
+kolab_folder_prop_ui_dialog_update_sensitivity (KolabFolderPropUIData *uidata)
+{
+	GtkWidget *widget = NULL;
+
+	g_return_if_fail (uidata != NULL);
+	g_return_if_fail (uidata->widgets != NULL);
+	g_return_if_fail (GTK_IS_DIALOG (uidata->widgets->dialog));
+	g_return_if_fail (GTK_IS_NOTEBOOK (uidata->widgets->notebook));
+	g_return_if_fail (uidata->meta_ui_data);
+	g_return_if_fail (uidata->meta_ui_data->widgets);
+	g_return_if_fail (uidata->perm_ui_data);
+	g_return_if_fail (uidata->perm_ui_data->widgets);
+
+	if (uidata->shell_context != KOLAB_FOLDER_CONTEXT_EMAIL)
+		goto skip_email;
+
+	/* in email view, we disable the PIM folder options */
+	widget = uidata->meta_ui_data->widgets->frame_options;
+	gtk_widget_set_sensitive (widget, FALSE);
+
+ skip_email:
+
+	if (! ((uidata->shell_context == KOLAB_FOLDER_CONTEXT_CALENDAR) ||
+	       (uidata->shell_context == KOLAB_FOLDER_CONTEXT_CONTACT)))
+		goto skip_pim;
+
+	/* in PIM view, we disable all IMAP stuff (for which we
+	 * need the CamelKolabIMAPXProvider, which is only available
+	 * in email view)
+	 */
+	widget = uidata->meta_ui_data->widgets->frame_type_select;
+	gtk_widget_set_sensitive (widget, FALSE);
+	widget = uidata->meta_ui_data->widgets->chk_btn_show_all;
+	gtk_widget_set_sensitive (widget, FALSE);
+	widget = uidata->perm_ui_data->widgets->container;
+	gtk_widget_set_sensitive (widget, FALSE);
+
+ skip_pim:
+
+	return;
+}
+
 static void
 kolab_folder_prop_ui_dialog_assemble (KolabFolderPropUIData *uidata)
 {
@@ -389,6 +437,7 @@ kolab_folder_prop_ui_dialog_assemble (KolabFolderPropUIData *uidata)
 	                                 C_("Kolab Folder Properties",
 	                                    "IMAP Access Control"));
 	gtk_widget_show_all (content);
+	kolab_folder_prop_ui_dialog_update_sensitivity (uidata);
 }
 
 static void
@@ -606,16 +655,8 @@ kolab_plugin_ui_update_source_entries_cb (EShellView *shell_view,
 	g_return_if_fail (E_IS_SHELL_VIEW (shell_view));
 	g_return_if_fail (entries != NULL);
 
-	if (strstr (entries->name, "calendar") != NULL)
-		group = "calendar";
-	else if (strstr (entries->name, "tasks") != NULL)
-		group = "tasks";
-	else if (strstr (entries->name, "memos") != NULL)
-		group = "memos";
-	else if (strstr (entries->name, "contacts") != NULL)
-		group = "contacts";
-	else
-		g_return_if_reached ();
+	group = e_kolab_plugin_util_group_name_from_action_entry_name (entries->name);
+	g_return_if_fail (group != NULL);
 
 	is_kolab_source = e_kolab_plugin_util_ui_get_selected_source (shell_view,
 	                                                              NULL);
@@ -675,16 +716,8 @@ kolab_plugin_ui_setup_source_actions (EShellView *shell_view,
 	g_return_if_fail (entries != NULL);
 	g_return_if_fail (n_entries == KOLAB_CONTEXT_NUM_ENTRIES);
 
-	if (strstr (entries->name, "calendar") != NULL)
-		group = "calendar";
-	else if (strstr (entries->name, "tasks") != NULL)
-		group = "tasks";
-	else if (strstr (entries->name, "memos") != NULL)
-		group = "memos";
-	else if (strstr (entries->name, "contacts") != NULL)
-		group = "contacts";
-	else
-		g_return_if_reached ();
+	group = e_kolab_plugin_util_group_name_from_action_entry_name (entries->name);
+	g_return_if_fail (group != NULL);
 
 	shell_window = e_shell_view_get_shell_window (shell_view);
 
