@@ -42,6 +42,9 @@
 
 /*----------------------------------------------------------------------------*/
 
+const gchar*
+e_kolab_plugin_util_group_name_from_action_entry_name (const gchar *entry_name);
+
 GtkWidget*
 e_kolab_plugin_util_ui_label_new (const gchar *text,
                                   gboolean add_bottom_space);
@@ -61,6 +64,12 @@ e_kolab_plugin_util_ui_dialog_set_button_sensitive (GtkDialog *dialog,
                                                     gboolean stock_check,
                                                     gboolean sensitive);
 
+KolabFolderTypeID
+e_kolab_plugin_util_ui_get_shell_type (EShellView *shell_view);
+
+KolabFolderContextID
+e_kolab_plugin_util_ui_get_shell_context (EShellView *shell_view);
+
 gboolean
 e_kolab_plugin_util_ui_get_selected_source (EShellView *shell_view,
                                             ESource **selected_source);
