@@ -32,6 +32,8 @@
 
 #include <config.h>
 
+#include <libekolab/e-source-kolab-folder.h>
+
 #include "e-kolab-plugin-types.h"
 #include "e-kolab-plugin-ui.h"
 #include "e-kolab-plugin.h"
@@ -45,14 +47,16 @@ gint
 e_plugin_lib_enable (EPlugin *epl,
                      gint enable)
 {
-	/* api demo */
-	g_assert (E_IS_PLUGIN (epl));
+	GType mytype = 0;
+
+	g_return_val_if_fail (E_IS_PLUGIN (epl), 0);
+
+	/* register kolab folder source type */
+	mytype = e_source_kolab_folder_get_type ();
+	g_debug ("%s(): %s registered",
+	         __func__, g_type_name (mytype));
+
 	if (enable) {
-		/* init stuff, call some libekolab/ init function here */
-		/*
-		  bindtextdomain(GETTEXT_PACKAGE, LOCALEDIR);
-		  bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
-		*/
 		g_debug ("%s(): Kolab plugin enabled", __func__);
 	} else {
 		g_debug ("%s(): Kolab plugin disabled", __func__);
