@@ -276,7 +276,7 @@ imapx_extd_store_delete_folder_sync (CamelStore *self,
 {
 	CamelIMAPXExtdStore *myself = NULL;
 	CamelIMAPXExtdStorePrivate *priv = NULL;
-	
+
 	gboolean ok = FALSE;
 
 	g_assert (CAMEL_IS_IMAPX_EXTD_STORE (self));
@@ -291,7 +291,7 @@ imapx_extd_store_delete_folder_sync (CamelStore *self,
 	if (ok) {
 		myself = CAMEL_IMAPX_EXTD_STORE (self);
 		priv = CAMEL_IMAPX_EXTD_STORE_PRIVATE (myself);
-		
+
 		/* delete folder metadata entry from our
 		 * hash table so we will not return a wrong
 		 * folder annotation if a folder with the
@@ -301,7 +301,7 @@ imapx_extd_store_delete_folder_sync (CamelStore *self,
 		(void) camel_imapx_metadata_remove_metadata (priv->md,
 		                                             foldername);
 	}
-	
+
 	return ok;
 }
 
@@ -557,6 +557,100 @@ imapx_extd_store_set_metadata (CamelIMAPXExtdStore *self,
 	return TRUE;
 }
 
+static CamelImapxAcl*
+imapx_extd_store_get_acl (CamelIMAPXExtdStore *self,
+                          CamelImapxAclSpec *spec,
+                          gboolean do_resect,
+                          GCancellable *cancellable,
+                          GError **err)
+{
+	CamelIMAPXExtdStorePrivate *priv = NULL;
+	CamelIMAPXServer *is = NULL;
+	CamelImapxAcl *acl = NULL;
+	GError *tmp_err = NULL;
+	gboolean ok = TRUE;
+
+	g_assert (CAMEL_IS_IMAPX_EXTD_STORE (self));
+	g_assert (spec != NULL);
+	g_assert (spec->mbox_name != NULL);
+	/* cancellable may be NULL */
+	g_return_val_if_fail (err == NULL || *err == NULL, NULL);
+
+	priv = CAMEL_IMAPX_EXTD_STORE_PRIVATE (self);
+
+	is = imapx_extd_store_get_server (CAMEL_IMAPX_STORE (self),
+	                                  NULL,
+	                                  cancellable,
+	                                  &tmp_err);
+	if (is == NULL)
+		goto exit;
+
+	if (spec->type & CAMEL_IMAPX_ACL_TYPE_GENERAL) {
+		ok = camel_imapx_extd_server_get_acl (is,
+		                                      spec->mbox_name,
+		                                      cancellable,
+		                                      &tmp_err);
+		if (! ok)
+			goto exit;
+	}
+
+	if (spec->type & CAMEL_IMAPX_ACL_TYPE_MYRIGHTS) {
+		ok = camel_imapx_extd_server_get_myrights (is,
+		                                           spec->mbox_name,
+		                                           cancellable,
+		                                           &tmp_err);
+		if (! ok)
+			goto exit;
+	}
+
+	if (do_resect)
+		acl = camel_imapx_acl_resect (priv->acl);
+
+ exit:
+	if (tmp_err != NULL)
+		g_propagate_error (err, tmp_err);
+
+	return acl;
+}
+
+static gboolean
+imapx_extd_store_set_acl (CamelIMAPXExtdStore *self,
+                          const gchar *foldername,
+                          const GList *entries,
+                          GCancellable *cancellable,
+                          GError **err)
+{
+	CamelIMAPXServer *is = NULL;
+	GError *tmp_err = NULL;
+	gboolean ok = FALSE;
+
+	g_assert (CAMEL_IS_IMAPX_EXTD_STORE (self));
+	g_assert (foldername != NULL);
+	/* entries may be NULL */
+	/* cancellable may be NULL */
+	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
+
+	is = imapx_extd_store_get_server (CAMEL_IMAPX_STORE (self),
+	                                  NULL,
+	                                  cancellable,
+	                                  &tmp_err);
+	if (is == NULL)
+		goto exit;
+
+	ok = camel_imapx_extd_server_set_acl (is,
+	                                      foldername,
+	                                      entries,
+	                                      cancellable,
+	                                      &tmp_err);
+ exit:
+	if (tmp_err != NULL) {
+		g_propagate_error (err, tmp_err);
+		ok = FALSE;
+	}
+
+	return ok;
+}
+
 /*----------------------------------------------------------------------------*/
 /* interface functions */
 
@@ -735,6 +829,8 @@ camel_imapx_extd_store_class_init (CamelIMAPXExtdStoreClass *klass)
 	klass->metadata_get_proto = imapx_extd_store_metadata_get_proto;
 	klass->get_metadata = imapx_extd_store_get_metadata;
 	klass->set_metadata = imapx_extd_store_set_metadata;
+	klass->get_acl = imapx_extd_store_get_acl;
+	klass->set_acl = imapx_extd_store_set_acl;
 }
 
 /*----------------------------------------------------------------------------*/
@@ -806,6 +902,44 @@ camel_imapx_extd_store_set_metadata (CamelIMAPXExtdStore *self,
 	                            err);
 }
 
+CamelImapxAcl*
+camel_imapx_extd_store_get_acl (CamelIMAPXExtdStore *self,
+                                CamelImapxAclSpec *spec,
+                                gboolean do_resect,
+                                GCancellable *cancellable,
+                                GError **err)
+{
+	CamelIMAPXExtdStoreClass *klass = NULL;
+
+	g_return_val_if_fail (CAMEL_IS_IMAPX_EXTD_STORE (self), FALSE);
+
+	klass = CAMEL_IMAPX_EXTD_STORE_GET_CLASS (self);
+	return klass->get_acl (self,
+	                       spec,
+	                       do_resect,
+	                       cancellable,
+	                       err);
+}
+
+gboolean
+camel_imapx_extd_store_set_acl (CamelIMAPXExtdStore *self,
+                                const gchar *foldername,
+                                const GList *entries,
+                                GCancellable *cancellable,
+                                GError **err)
+{
+	CamelIMAPXExtdStoreClass *klass = NULL;
+
+	g_return_val_if_fail (CAMEL_IS_IMAPX_EXTD_STORE (self), FALSE);
+
+	klass = CAMEL_IMAPX_EXTD_STORE_GET_CLASS (self);
+	return klass->set_acl (self,
+	                       foldername,
+	                       entries,
+	                       cancellable,
+	                       err);
+}
+
 /*----------------------------------------------------------------------------*/
 /* "friend" API */
 
