@@ -35,6 +35,7 @@
 #include <libekolabutil/kolab-util-camel.h>
 #include <libekolabutil/kolab-util-glib.h>
 
+#include "e-source-kolab-folder.h"
 #include "kolab-util-backend.h"
 #include "kolab-settings-handler.h"
 
@@ -43,6 +44,7 @@
 struct _KolabSettingsHandlerPrivate
 {
 	CamelKolabIMAPXSettings *camel_settings;
+	EBackend *e_backend;
 
 	gboolean is_configured;
 	gboolean is_up;
@@ -51,13 +53,12 @@ struct _KolabSettingsHandlerPrivate
 	guint    sdata_uint[KOLAB_SETTINGS_HANDLER_UINT_LAST_FIELD];
 	gint     sdata_int[KOLAB_SETTINGS_HANDLER_INT_LAST_FIELD];
 	gboolean sdata_bool[KOLAB_SETTINGS_HANDLER_BOOL_LAST_FIELD];
-
-	GHashTable *sdata_tbl;
 };
 
 enum {
 	PROP_0,
-	PROP_CAMEL_SETTINGS
+	PROP_CAMEL_SETTINGS,
+	PROP_E_BACKEND
 };
 
 #define KOLAB_SETTINGS_HANDLER_PRIVATE(obj)  (G_TYPE_INSTANCE_GET_PRIVATE ((obj), KOLAB_TYPE_SETTINGS_HANDLER, KolabSettingsHandlerPrivate))
@@ -79,14 +80,21 @@ static gboolean settings_handler_char_get_func_camel_cache_dir (KolabSettingsHan
 static gboolean settings_handler_char_set_func_camel_cache_dir (KolabSettingsHandler*, gchar*, GError**);
 static gboolean settings_handler_char_get_func_camel_config_dir (KolabSettingsHandler*, GError**);
 static gboolean settings_handler_char_set_func_camel_config_dir (KolabSettingsHandler*, gchar*, GError**);
-static gboolean settings_handler_uint_set_func_folder_context (KolabSettingsHandler*, guint value, GError**);
+static gboolean settings_handler_char_get_func_user_home_dir (KolabSettingsHandler*, GError**);
+static gboolean settings_handler_char_set_func_user_home_dir (KolabSettingsHandler*, gchar*, GError**);
+static gboolean settings_handler_char_get_func_esource_uid (KolabSettingsHandler*, GError**);
+static gboolean settings_handler_char_set_func_esource_uid (KolabSettingsHandler*, gchar*, GError**);
+static gboolean settings_handler_uint_set_func_folder_context (KolabSettingsHandler*, guint, GError**);
+static gboolean settings_handler_uint_get_func_folder_syncstrategy (KolabSettingsHandler*, GError**);
+static gboolean settings_handler_uint_set_func_folder_syncstrategy (KolabSettingsHandler*, guint, GError**);
 
 static KolabSettingsHandlerGetFunc _kolab_settings_handler_char_get_funcs[] = {
 	settings_handler_char_get_func_camel_data_dir, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_CAMEL_DATA_DIR */
 	settings_handler_char_get_func_camel_cache_dir, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_CAMEL_CACHE_DIR */
 	settings_handler_char_get_func_camel_config_dir, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_CAMEL_CONFIG_DIR */
 	NULL, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_CAMEL_ACCOUNT_DIR */
-	NULL, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_ESOURCE_UID */
+	settings_handler_char_get_func_user_home_dir, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_USER_HOME_DIR */
+	settings_handler_char_get_func_esource_uid, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_ESOURCE_UID */
 	NULL, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_KOLAB_USER_PASSWORD */
 };
 
@@ -95,22 +103,26 @@ static KolabSettingsHandlerCharSetFunc _kolab_settings_handler_char_set_funcs[]
 	settings_handler_char_set_func_camel_cache_dir, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_CAMEL_CACHE_DIR */
 	settings_handler_char_set_func_camel_config_dir, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_CAMEL_CONFIG_DIR */
 	NULL, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_CAMEL_ACCOUNT_DIR */
-	NULL, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_ESOURCE_UID */
+	settings_handler_char_set_func_user_home_dir, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_USER_HOME_DIR */
+	settings_handler_char_set_func_esource_uid, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_ESOURCE_UID */
 	NULL, /* KOLAB_SETTINGS_HANDLER_CHAR_FIELD_KOLAB_USER_PASSWORD */
 };
 
 static KolabSettingsHandlerGetFunc _kolab_settings_handler_uint_get_funcs[] = {
-	NULL /* KOLAB_SETTINGS_HANDLER_UINT_FIELD_FOLDER_CONTEXT */
+	NULL, /* KOLAB_SETTINGS_HANDLER_UINT_FIELD_FOLDER_CONTEXT */
+	settings_handler_uint_get_func_folder_syncstrategy /* KOLAB_SETTINGS_HANDLER_UINT_FIELD_FOLDER_SYNCSTRATEGY */
 };
 
 static KolabSettingsHandlerUintSetFunc _kolab_settings_handler_uint_set_funcs[] = {
-	settings_handler_uint_set_func_folder_context /* KOLAB_SETTINGS_HANDLER_UINT_FIELD_FOLDER_CONTEXT */
+	settings_handler_uint_set_func_folder_context, /* KOLAB_SETTINGS_HANDLER_UINT_FIELD_FOLDER_CONTEXT */
+	settings_handler_uint_set_func_folder_syncstrategy /* KOLAB_SETTINGS_HANDLER_UINT_FIELD_FOLDER_SYNCSTRATEGY */
 };
 
 /*----------------------------------------------------------------------------*/
 
 static gboolean
-settings_handler_char_get_func_camel_data_dir (KolabSettingsHandler *self, GError **err)
+settings_handler_char_get_func_camel_data_dir (KolabSettingsHandler *self,
+                                               GError **err)
 {
 	KolabSettingsHandlerPrivate *priv = NULL;
 	KolabFolderContextID context = KOLAB_FOLDER_CONTEXT_INVAL;
@@ -118,7 +130,7 @@ settings_handler_char_get_func_camel_data_dir (KolabSettingsHandler *self, GErro
 	gchar *priv_data_dir = NULL;
 	gchar *backend_dir = NULL;
 
-	g_assert (KOLAB_IS_SETTINGS_HANDLER (self));
+	g_return_val_if_fail (KOLAB_IS_SETTINGS_HANDLER (self), FALSE);
 	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
 
 	priv = KOLAB_SETTINGS_HANDLER_PRIVATE (self);
@@ -165,7 +177,8 @@ settings_handler_char_get_func_camel_data_dir (KolabSettingsHandler *self, GErro
 }
 
 static gboolean
-settings_handler_char_get_func_camel_cache_dir (KolabSettingsHandler *self, GError **err)
+settings_handler_char_get_func_camel_cache_dir (KolabSettingsHandler *self,
+                                                GError **err)
 {
 	KolabSettingsHandlerPrivate *priv = NULL;
 	KolabFolderContextID context = KOLAB_FOLDER_CONTEXT_INVAL;
@@ -173,7 +186,7 @@ settings_handler_char_get_func_camel_cache_dir (KolabSettingsHandler *self, GErr
 	gchar *priv_cache_dir = NULL;
 	gchar *backend_dir = NULL;
 
-	g_assert (KOLAB_IS_SETTINGS_HANDLER (self));
+	g_return_val_if_fail (KOLAB_IS_SETTINGS_HANDLER (self), FALSE);
 	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
 
 	priv = KOLAB_SETTINGS_HANDLER_PRIVATE (self);
@@ -220,10 +233,36 @@ settings_handler_char_get_func_camel_cache_dir (KolabSettingsHandler *self, GErr
 }
 
 static gboolean
-settings_handler_char_set_func_camel_data_dir (KolabSettingsHandler *self, gchar *value, GError **err)
+settings_handler_char_get_func_user_home_dir (KolabSettingsHandler *self,
+                                              GError **err)
 {
-	(void)self;
+	KolabSettingsHandlerPrivate *priv = NULL;
+	gchar *home_dir = NULL;
+
+	g_return_val_if_fail (KOLAB_IS_SETTINGS_HANDLER (self), FALSE);
+	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
+
+	priv = KOLAB_SETTINGS_HANDLER_PRIVATE (self);
+
+	home_dir = priv->sdata_char[KOLAB_SETTINGS_HANDLER_CHAR_FIELD_USER_HOME_DIR];
+	if (home_dir != NULL)
+		return TRUE;
+
+	home_dir = g_strdup (g_get_home_dir ());
+
+	priv->sdata_char[KOLAB_SETTINGS_HANDLER_CHAR_FIELD_USER_HOME_DIR] = home_dir;
+	return TRUE;
+}
+
+static gboolean
+settings_handler_char_set_func_camel_data_dir (KolabSettingsHandler *self,
+                                               gchar *value,
+                                               GError **err)
+{
+	g_return_val_if_fail (KOLAB_IS_SETTINGS_HANDLER (self), FALSE);
 	(void)value;
+	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
+
 	g_set_error (err,
 	             KOLAB_BACKEND_ERROR,
 	             KOLAB_BACKEND_ERROR_GENERIC,
@@ -232,28 +271,100 @@ settings_handler_char_set_func_camel_data_dir (KolabSettingsHandler *self, gchar
 }
 
 static gboolean
-settings_handler_char_set_func_camel_cache_dir (KolabSettingsHandler *self, gchar *value, GError **err)
+settings_handler_char_set_func_camel_cache_dir (KolabSettingsHandler *self,
+                                                gchar *value,
+                                                GError **err)
 {
-	(void)self;
+	g_return_val_if_fail (KOLAB_IS_SETTINGS_HANDLER (self), FALSE);
 	(void)value;
-	/* FIXME mark as a translatable string */
+	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
+
 	g_set_error (err,
 	             KOLAB_BACKEND_ERROR,
 	             KOLAB_BACKEND_ERROR_GENERIC,
-	             "Cannot set Camel cache directory, it is a read-only resource");
+	             _("Cannot set Camel cache directory, it is a read-only resource"));
 	return FALSE;
 }
 
 static gboolean
-settings_handler_char_get_func_camel_config_dir (KolabSettingsHandler *self, GError **err)
+settings_handler_char_set_func_user_home_dir (KolabSettingsHandler *self,
+                                              gchar *value,
+                                              GError **err)
 {
-	KolabSettingsHandlerPrivate *priv = KOLAB_SETTINGS_HANDLER_PRIVATE (self);
+	g_return_val_if_fail (KOLAB_IS_SETTINGS_HANDLER (self), FALSE);
+	(void)value;
+	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
+
+	g_set_error (err,
+	             KOLAB_BACKEND_ERROR,
+	             KOLAB_BACKEND_ERROR_GENERIC,
+	             _("Cannot set user home directory, it is a read-only resource"));
+	return FALSE;
+}
+
+static gboolean
+settings_handler_char_get_func_esource_uid (KolabSettingsHandler *self,
+                                            GError **err)
+{
+	KolabSettingsHandlerPrivate *priv = NULL;
+	ESource *esource = NULL;
+	gchar *uid = NULL;
+
+	g_return_val_if_fail (KOLAB_IS_SETTINGS_HANDLER (self), FALSE);
+	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
+
+	priv = KOLAB_SETTINGS_HANDLER_PRIVATE (self);
+	g_return_val_if_fail (E_IS_BACKEND (priv->e_backend), FALSE);
+
+	esource = e_backend_get_source (priv->e_backend);
+	if (! E_IS_SOURCE (esource)) {
+		g_set_error (err,
+		             KOLAB_BACKEND_ERROR,
+		             KOLAB_BACKEND_ERROR_GENERIC,
+		             _("Could not get ESource for backend"));
+		return FALSE;
+	}
+
+	uid = g_strdup (e_source_get_uid (esource));
+	if (priv->sdata_char[KOLAB_SETTINGS_HANDLER_CHAR_FIELD_ESOURCE_UID] != NULL)
+		g_free (priv->sdata_char[KOLAB_SETTINGS_HANDLER_CHAR_FIELD_ESOURCE_UID]);
+	priv->sdata_char[KOLAB_SETTINGS_HANDLER_CHAR_FIELD_ESOURCE_UID] = uid;
+
+	return TRUE;
+}
+
+static gboolean
+settings_handler_char_set_func_esource_uid (KolabSettingsHandler *self,
+                                            gchar *value,
+                                            GError **err)
+{
+	g_return_val_if_fail (KOLAB_IS_SETTINGS_HANDLER (self), FALSE);
+	(void)value;
+	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
+
+	g_set_error (err,
+	             KOLAB_BACKEND_ERROR,
+	             KOLAB_BACKEND_ERROR_GENERIC,
+	             _("Cannot set ESource UID, it is a read-only resource"));
+	return FALSE;
+}
+
+static gboolean
+settings_handler_char_get_func_camel_config_dir (KolabSettingsHandler *self,
+                                                 GError **err)
+{
+	KolabSettingsHandlerPrivate *priv = NULL;
 	gboolean ok = FALSE;
 	const gchar *data_dir = NULL;
 	gchar *config_dir = NULL;
 	gchar *priv_config_dir = NULL;
 	GError *tmp_err = NULL;
 
+	g_return_val_if_fail (KOLAB_IS_SETTINGS_HANDLER (self), FALSE);
+	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
+
+	priv = KOLAB_SETTINGS_HANDLER_PRIVATE (self);
+
 	priv_config_dir = priv->sdata_char[KOLAB_SETTINGS_HANDLER_CHAR_FIELD_CAMEL_CONFIG_DIR];
 	if (priv_config_dir != NULL)
 		return TRUE;
@@ -283,10 +394,14 @@ settings_handler_char_get_func_camel_config_dir (KolabSettingsHandler *self, GEr
 }
 
 static gboolean
-settings_handler_char_set_func_camel_config_dir (KolabSettingsHandler *self, gchar *value, GError **err)
+settings_handler_char_set_func_camel_config_dir (KolabSettingsHandler *self,
+                                                 gchar *value,
+                                                 GError **err)
 {
-	(void)self;
+	g_return_val_if_fail (KOLAB_IS_SETTINGS_HANDLER (self), FALSE);
 	(void)value;
+	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
+
 	g_set_error (err,
 	             KOLAB_BACKEND_ERROR,
 	             KOLAB_BACKEND_ERROR_GENERIC,
@@ -295,10 +410,14 @@ settings_handler_char_set_func_camel_config_dir (KolabSettingsHandler *self, gch
 }
 
 static gboolean
-settings_handler_uint_set_func_folder_context (KolabSettingsHandler *self, guint value, GError **err)
+settings_handler_uint_set_func_folder_context (KolabSettingsHandler *self,
+                                               guint value,
+                                               GError **err)
 {
-	(void)self;
+	g_return_val_if_fail (KOLAB_IS_SETTINGS_HANDLER (self), FALSE);
 	(void)value;
+	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
+
 	g_set_error (err,
 	             KOLAB_BACKEND_ERROR,
 	             KOLAB_BACKEND_ERROR_GENERIC,
@@ -306,6 +425,61 @@ settings_handler_uint_set_func_folder_context (KolabSettingsHandler *self, guint
 	return FALSE;
 }
 
+static gboolean
+settings_handler_uint_get_func_folder_syncstrategy (KolabSettingsHandler *self,
+                                                    GError **err)
+{
+	KolabSettingsHandlerPrivate *priv = NULL;
+	ESource *esource = NULL;
+	ESourceKolabFolder *extension = NULL;
+	KolabSyncStrategyID strategy = KOLAB_SYNC_STRATEGY_DEFAULT;
+
+	g_return_val_if_fail (KOLAB_IS_SETTINGS_HANDLER (self), FALSE);
+	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
+
+	priv = KOLAB_SETTINGS_HANDLER_PRIVATE (self);
+	g_return_val_if_fail (E_IS_BACKEND (priv->e_backend), FALSE);
+
+	esource = e_backend_get_source (priv->e_backend);
+	if (! E_IS_SOURCE (esource)) {
+		g_set_error (err,
+		             KOLAB_BACKEND_ERROR,
+		             KOLAB_BACKEND_ERROR_GENERIC,
+		             _("Could not get ESource for backend"));
+		return FALSE;
+	}
+
+	if (! e_source_has_extension (esource, E_SOURCE_EXTENSION_KOLAB_FOLDER)) {
+		g_set_error (err,
+		             KOLAB_BACKEND_ERROR,
+		             KOLAB_BACKEND_ERROR_GENERIC,
+		             _("ESource for backend has no 'Kolab Folder' extension"));
+		return FALSE;
+	}
+
+	extension = e_source_get_extension (esource, E_SOURCE_EXTENSION_KOLAB_FOLDER);
+	strategy = e_source_kolab_folder_get_sync_strategy (extension);
+	priv->sdata_uint[KOLAB_SETTINGS_HANDLER_UINT_FIELD_FOLDER_SYNCSTRATEGY] = strategy;
+
+	return TRUE;
+}
+
+static gboolean
+settings_handler_uint_set_func_folder_syncstrategy (KolabSettingsHandler *self,
+                                                    guint value,
+                                                    GError **err)
+{
+	g_return_val_if_fail (KOLAB_IS_SETTINGS_HANDLER (self), FALSE);
+	(void)value;
+	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
+
+	g_set_error (err,
+	             KOLAB_BACKEND_ERROR,
+	             KOLAB_BACKEND_ERROR_GENERIC,
+	             _("Cannot set Kolab Folder Sync Strategy, it is a read-only resource"));
+	return FALSE;
+}
+
 /*----------------------------------------------------------------------------*/
 
 static void
@@ -314,7 +488,7 @@ kolab_settings_handler_init (KolabSettingsHandler *self)
 	KolabSettingsHandlerPrivate *priv = NULL;
 	gint ii = 0;
 
-	g_assert (KOLAB_IS_SETTINGS_HANDLER (self));
+	g_return_if_fail (KOLAB_IS_SETTINGS_HANDLER (self));
 
 	priv = self->priv = KOLAB_SETTINGS_HANDLER_PRIVATE (self);
 
@@ -329,6 +503,7 @@ kolab_settings_handler_init (KolabSettingsHandler *self)
 
 	/* documenting initial settings (dumb fallback values) */
 	priv->sdata_uint[KOLAB_SETTINGS_HANDLER_UINT_FIELD_FOLDER_CONTEXT] = KOLAB_FOLDER_CONTEXT_INVAL;
+	priv->sdata_uint[KOLAB_SETTINGS_HANDLER_UINT_FIELD_FOLDER_SYNCSTRATEGY] = KOLAB_SYNC_STRATEGY_DEFAULT;
 	priv->sdata_int[KOLAB_SETTINGS_HANDLER_INT_FIELD_KOLAB_SERVER_IMAP_PORT]  = KOLAB_SERVER_IMAP_PORT;
 	priv->sdata_int[KOLAB_SETTINGS_HANDLER_INT_FIELD_KOLAB_SERVER_IMAPS_PORT] = KOLAB_SERVER_IMAPS_PORT;
 	priv->sdata_int[KOLAB_SETTINGS_HANDLER_INT_FIELD_KOLAB_SERVER_HTTP_PORT]  = KOLAB_SERVER_HTTP_PORT;
@@ -336,8 +511,6 @@ kolab_settings_handler_init (KolabSettingsHandler *self)
 	priv->sdata_int[KOLAB_SETTINGS_HANDLER_INT_FIELD_KOLAB_SERVER_LDAP_PORT]  = KOLAB_SERVER_LDAP_PORT;
 	priv->sdata_int[KOLAB_SETTINGS_HANDLER_INT_FIELD_KOLAB_SERVER_LDAPS_PORT] = KOLAB_SERVER_LDAPS_PORT;
 
-	priv->sdata_tbl = NULL;
-
 	priv->is_configured = FALSE;
 	priv->is_up = FALSE;
 }
@@ -352,6 +525,16 @@ kolab_settings_handler_set_camel_settings (KolabSettingsHandler *ksettings,
 	ksettings->priv->camel_settings = g_object_ref (camel_settings);
 }
 
+static void
+kolab_settings_handler_set_e_backend (KolabSettingsHandler *ksettings,
+                                      EBackend *e_backend)
+{
+	g_return_if_fail (E_IS_BACKEND (e_backend));
+	g_return_if_fail (ksettings->priv->e_backend == NULL);
+
+	ksettings->priv->e_backend = g_object_ref (e_backend);
+}
+
 static void
 kolab_settings_handler_set_property (GObject *object,
                                      guint property_id,
@@ -359,13 +542,18 @@ kolab_settings_handler_set_property (GObject *object,
                                      GParamSpec *pspec)
 {
 	switch (property_id) {
-		case PROP_CAMEL_SETTINGS:
-			kolab_settings_handler_set_camel_settings (
-				KOLAB_SETTINGS_HANDLER (object),
-				g_value_get_object (value));
-			return;
-		default:
-			break;
+	case PROP_CAMEL_SETTINGS:
+		kolab_settings_handler_set_camel_settings (
+		                                           KOLAB_SETTINGS_HANDLER (object),
+		                                           g_value_get_object (value));
+		return;
+	case PROP_E_BACKEND:
+		kolab_settings_handler_set_e_backend (
+		                                      KOLAB_SETTINGS_HANDLER (object),
+		                                      g_value_get_object (value));
+		return;
+	default:
+		break;
 	}
 
 	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -378,14 +566,20 @@ kolab_settings_handler_get_property (GObject *object,
                                      GParamSpec *pspec)
 {
 	switch (property_id) {
-		case PROP_CAMEL_SETTINGS:
-			g_value_set_object (
-				value,
-				kolab_settings_handler_get_camel_settings (
-				KOLAB_SETTINGS_HANDLER (object)));
-			return;
-		default:
-			break;
+	case PROP_CAMEL_SETTINGS:
+		g_value_set_object (
+		                    value,
+		                    kolab_settings_handler_get_camel_settings (
+		                                                               KOLAB_SETTINGS_HANDLER (object)));
+		return;
+	case PROP_E_BACKEND:
+		g_value_set_object (
+		                    value,
+		                    kolab_settings_handler_get_e_backend (
+		                                                          KOLAB_SETTINGS_HANDLER (object)));
+		return;
+	default:
+		break;
 	}
 
 	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -403,6 +597,11 @@ kolab_settings_handler_dispose (GObject *object)
 		priv->camel_settings = NULL;
 	}
 
+	if (priv->e_backend != NULL) {
+		g_object_unref (priv->e_backend);
+		priv->e_backend = NULL;
+	}
+
 	G_OBJECT_CLASS (kolab_settings_handler_parent_class)->dispose (object);
 }
 
@@ -421,9 +620,6 @@ kolab_settings_handler_finalize (GObject *object)
 			g_free (priv->sdata_char[ii]);
 	}
 
-	if (priv->sdata_tbl != NULL)
-		g_hash_table_destroy (priv->sdata_tbl);
-
 	G_OBJECT_CLASS (kolab_settings_handler_parent_class)->finalize (object);
 }
 
@@ -440,26 +636,44 @@ kolab_settings_handler_class_init (KolabSettingsHandlerClass *klass)
 	object_class->dispose = kolab_settings_handler_dispose;
 	object_class->finalize = kolab_settings_handler_finalize;
 
-	g_object_class_install_property (
-		object_class,
-		PROP_CAMEL_SETTINGS,
-		g_param_spec_object (
-			"camel-settings",
-			"Camel Settings",
-			"An authoritative CamelKolabIMAPXSettings",
-			CAMEL_TYPE_KOLAB_IMAPX_SETTINGS,
-			G_PARAM_READWRITE |
-			G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (object_class,
+	                                 PROP_CAMEL_SETTINGS,
+	                                 g_param_spec_object ("camel-settings",
+	                                                      "Camel Settings",
+	                                                      "An authoritative CamelKolabIMAPXSettings",
+	                                                      CAMEL_TYPE_KOLAB_IMAPX_SETTINGS,
+	                                                      G_PARAM_READWRITE |
+	                                                      G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (object_class,
+	                                 PROP_E_BACKEND,
+	                                 g_param_spec_object ("e-backend",
+	                                                      "EBackend",
+	                                                      "An EBackend instance",
+	                                                      E_TYPE_BACKEND,
+	                                                      G_PARAM_READWRITE|
+	                                                      G_PARAM_CONSTRUCT_ONLY));
 }
 
 KolabSettingsHandler *
-kolab_settings_handler_new (CamelKolabIMAPXSettings *camel_settings)
+kolab_settings_handler_new (CamelKolabIMAPXSettings *camel_settings,
+                            EBackend *e_backend)
 {
-	g_return_val_if_fail (CAMEL_IS_KOLAB_IMAPX_SETTINGS (camel_settings), NULL);
+	KolabSettingsHandler *ksettings = NULL;
 
-	return g_object_new (
-		KOLAB_TYPE_SETTINGS_HANDLER,
-		"camel-settings", camel_settings, NULL);
+	g_return_val_if_fail (CAMEL_IS_KOLAB_IMAPX_SETTINGS (camel_settings), NULL);
+	/* backend may be NULL */
+
+	if (e_backend != NULL)
+		ksettings = g_object_new (KOLAB_TYPE_SETTINGS_HANDLER,
+		                          "camel-settings", camel_settings,
+		                          "e-backend", e_backend,
+		                          NULL);
+	else
+		ksettings = g_object_new (KOLAB_TYPE_SETTINGS_HANDLER,
+		                          "camel-settings", camel_settings,
+		                          NULL);
+
+	return ksettings;
 }
 
 /*----------------------------------------------------------------------------*/
@@ -486,9 +700,9 @@ kolab_settings_handler_configure  (KolabSettingsHandler *self,
 {
 	KolabSettingsHandlerPrivate *priv = NULL;
 
-	g_assert (KOLAB_IS_SETTINGS_HANDLER (self));
-	g_assert ((context > KOLAB_FOLDER_CONTEXT_INVAL) &&
-	          (context < KOLAB_FOLDER_LAST_CONTEXT));
+	g_return_val_if_fail (KOLAB_IS_SETTINGS_HANDLER (self), FALSE);
+	g_return_val_if_fail ((context > KOLAB_FOLDER_CONTEXT_INVAL) &&
+	                      (context < KOLAB_FOLDER_LAST_CONTEXT), FALSE);
 	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
 
 	priv = KOLAB_SETTINGS_HANDLER_PRIVATE (self);
@@ -522,13 +736,13 @@ kolab_settings_handler_bringup (KolabSettingsHandler *self,
 {
 	KolabSettingsHandlerPrivate *priv = NULL;
 
-	g_assert (KOLAB_IS_SETTINGS_HANDLER (self));
+	g_return_val_if_fail (KOLAB_IS_SETTINGS_HANDLER (self), FALSE);
 	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
 
 	priv = KOLAB_SETTINGS_HANDLER_PRIVATE (self);
 
-	g_assert (priv->is_configured == TRUE);
-	g_assert (priv->is_up == FALSE);
+	g_return_val_if_fail (priv->is_configured == TRUE, FALSE);
+	g_return_val_if_fail (priv->is_up == FALSE, FALSE);
 
 	/* TODO implement me */
 
@@ -554,7 +768,7 @@ kolab_settings_handler_shutdown (KolabSettingsHandler *self,
 {
 	KolabSettingsHandlerPrivate *priv = NULL;
 
-	g_assert (KOLAB_IS_SETTINGS_HANDLER (self));
+	g_return_val_if_fail (KOLAB_IS_SETTINGS_HANDLER (self), FALSE);
 	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
 
 	priv = KOLAB_SETTINGS_HANDLER_PRIVATE (self);
@@ -574,11 +788,19 @@ kolab_settings_handler_shutdown (KolabSettingsHandler *self,
 CamelKolabIMAPXSettings *
 kolab_settings_handler_get_camel_settings (KolabSettingsHandler *self)
 {
-	g_assert (KOLAB_IS_SETTINGS_HANDLER (self));
+	g_return_val_if_fail (KOLAB_IS_SETTINGS_HANDLER (self), NULL);
 
 	return self->priv->camel_settings;
 }
 
+EBackend *
+kolab_settings_handler_get_e_backend (KolabSettingsHandler *self)
+{
+	g_return_val_if_fail (KOLAB_IS_SETTINGS_HANDLER (self), NULL);
+
+	return self->priv->e_backend;
+}
+
 /**
  * kolab_settings_handler_set_char_field:
  * @self: a #KolabSettingsHandler instance
@@ -606,15 +828,15 @@ kolab_settings_handler_set_char_field (KolabSettingsHandler *self,
 	gboolean ok = FALSE;
 	GError *tmp_err = NULL;
 
-	g_assert (KOLAB_IS_SETTINGS_HANDLER (self));
-	g_assert (field_id < KOLAB_SETTINGS_HANDLER_CHAR_LAST_FIELD);
+	g_return_val_if_fail (KOLAB_IS_SETTINGS_HANDLER (self), FALSE);
+	g_return_val_if_fail (field_id < KOLAB_SETTINGS_HANDLER_CHAR_LAST_FIELD, FALSE);
 	/* value may be NULL */
 	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
 
 	priv = KOLAB_SETTINGS_HANDLER_PRIVATE (self);
 
-	g_assert (priv->is_configured == TRUE);
-	g_assert (priv->is_up == TRUE);
+	g_return_val_if_fail (priv->is_configured == TRUE, FALSE);
+	g_return_val_if_fail (priv->is_up == TRUE, FALSE);
 
 	setfunc = _kolab_settings_handler_char_set_funcs[field_id];
 	if (setfunc != NULL) {
@@ -653,14 +875,14 @@ kolab_settings_handler_get_char_field (KolabSettingsHandler *self,
 	gboolean ok = FALSE;
 	GError *tmp_err = NULL;
 
-	g_assert (KOLAB_IS_SETTINGS_HANDLER (self));
-	g_assert (field_id < KOLAB_SETTINGS_HANDLER_CHAR_LAST_FIELD);
+	g_return_val_if_fail (KOLAB_IS_SETTINGS_HANDLER (self), NULL);
+	g_return_val_if_fail (field_id < KOLAB_SETTINGS_HANDLER_CHAR_LAST_FIELD, NULL);
 	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
 
 	priv = KOLAB_SETTINGS_HANDLER_PRIVATE (self);
 
-	g_assert (priv->is_configured == TRUE);
-	g_assert (priv->is_up == TRUE);
+	g_return_val_if_fail (priv->is_configured == TRUE, NULL);
+	g_return_val_if_fail (priv->is_up == TRUE, NULL);
 
 	getfunc = _kolab_settings_handler_char_get_funcs[field_id];
 	if (getfunc != NULL) {
@@ -699,14 +921,14 @@ kolab_settings_handler_set_uint_field (KolabSettingsHandler *self,
 	gboolean ok = FALSE;
 	GError *tmp_err = NULL;
 
-	g_assert (KOLAB_IS_SETTINGS_HANDLER (self));
-	g_assert (field_id < KOLAB_SETTINGS_HANDLER_UINT_LAST_FIELD);
+	g_return_val_if_fail (KOLAB_IS_SETTINGS_HANDLER (self), FALSE);
+	g_return_val_if_fail (field_id < KOLAB_SETTINGS_HANDLER_UINT_LAST_FIELD, FALSE);
 	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
 
 	priv = KOLAB_SETTINGS_HANDLER_PRIVATE (self);
 
-	g_assert (priv->is_configured == TRUE);
-	g_assert (priv->is_up == TRUE);
+	g_return_val_if_fail (priv->is_configured == TRUE, FALSE);
+	g_return_val_if_fail (priv->is_up == TRUE, FALSE);
 
 	setfunc = _kolab_settings_handler_uint_set_funcs[field_id];
 	if (setfunc != NULL) {
@@ -743,14 +965,14 @@ kolab_settings_handler_get_uint_field (KolabSettingsHandler *self,
 	gboolean ok = FALSE;
 	GError *tmp_err = NULL;
 
-	g_assert (KOLAB_IS_SETTINGS_HANDLER (self));
-	g_assert (field_id < KOLAB_SETTINGS_HANDLER_UINT_LAST_FIELD);
-	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
+	g_return_val_if_fail (KOLAB_IS_SETTINGS_HANDLER (self), 0);
+	g_return_val_if_fail (field_id < KOLAB_SETTINGS_HANDLER_UINT_LAST_FIELD, 0);
+	g_return_val_if_fail (err == NULL || *err == NULL, 0);
 
 	priv = KOLAB_SETTINGS_HANDLER_PRIVATE (self);
 
-	g_assert (priv->is_configured == TRUE);
-	g_assert (priv->is_up == TRUE);
+	g_return_val_if_fail (priv->is_configured == TRUE, 0);
+	g_return_val_if_fail (priv->is_up == TRUE, 0);
 
 	getfunc = _kolab_settings_handler_uint_get_funcs[field_id];
 	if (getfunc != NULL) {
@@ -786,14 +1008,14 @@ kolab_settings_handler_set_int_field (KolabSettingsHandler *self,
 {
 	KolabSettingsHandlerPrivate *priv = NULL;
 
-	g_assert (KOLAB_IS_SETTINGS_HANDLER (self));
+	g_return_val_if_fail (KOLAB_IS_SETTINGS_HANDLER (self), FALSE);
 	/* g_assert (field_id < KOLAB_SETTINGS_HANDLER_INT_LAST_FIELD); */
 	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
 
 	priv = KOLAB_SETTINGS_HANDLER_PRIVATE (self);
 
-	g_assert (priv->is_configured == TRUE);
-	g_assert (priv->is_up == TRUE);
+	g_return_val_if_fail (priv->is_configured == TRUE, FALSE);
+	g_return_val_if_fail (priv->is_up == TRUE, FALSE);
 
 	priv->sdata_int[field_id] = value;
 	return TRUE;
@@ -818,14 +1040,14 @@ kolab_settings_handler_get_int_field (KolabSettingsHandler *self,
 {
 	KolabSettingsHandlerPrivate *priv = NULL;
 
-	g_assert (KOLAB_IS_SETTINGS_HANDLER (self));
+	g_return_val_if_fail (KOLAB_IS_SETTINGS_HANDLER (self), 0);
 	/* g_assert (field_id < KOLAB_SETTINGS_HANDLER_INT_LAST_FIELD); */
 	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
 
 	priv = KOLAB_SETTINGS_HANDLER_PRIVATE (self);
 
-	g_assert (priv->is_configured == TRUE);
-	g_assert (priv->is_up == TRUE);
+	g_return_val_if_fail (priv->is_configured == TRUE, 0);
+	g_return_val_if_fail (priv->is_up == TRUE, 0);
 
 	return priv->sdata_int[field_id];
 }
@@ -852,14 +1074,14 @@ kolab_settings_handler_set_bool_field (KolabSettingsHandler *self,
 {
 	KolabSettingsHandlerPrivate *priv = NULL;
 
-	g_assert (KOLAB_IS_SETTINGS_HANDLER (self));
+	g_return_val_if_fail (KOLAB_IS_SETTINGS_HANDLER (self), FALSE);
 	/* g_assert (field_id < KOLAB_SETTINGS_HANDLER_BOOL_LAST_FIELD); */
 	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
 
 	priv = KOLAB_SETTINGS_HANDLER_PRIVATE (self);
 
-	g_assert (priv->is_configured == TRUE);
-	g_assert (priv->is_up == TRUE);
+	g_return_val_if_fail (priv->is_configured == TRUE, FALSE);
+	g_return_val_if_fail (priv->is_up == TRUE, FALSE);
 
 	priv->sdata_bool[field_id] = value;
 	return TRUE;
@@ -884,175 +1106,16 @@ kolab_settings_handler_get_bool_field (KolabSettingsHandler *self,
 {
 	KolabSettingsHandlerPrivate *priv = NULL;
 
-	g_assert (KOLAB_IS_SETTINGS_HANDLER (self));
+	g_return_val_if_fail (KOLAB_IS_SETTINGS_HANDLER (self), FALSE);
 	/* g_assert (field_id < KOLAB_SETTINGS_HANDLER_BOOL_LAST_FIELD); */
 	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
 
 	priv = KOLAB_SETTINGS_HANDLER_PRIVATE (self);
 
-	g_assert (priv->is_configured == TRUE);
-	g_assert (priv->is_up == TRUE);
+	g_return_val_if_fail (priv->is_configured == TRUE, FALSE);
+	g_return_val_if_fail (priv->is_up == TRUE, FALSE);
 
 	return priv->sdata_bool[field_id];
 }
 
 /*----------------------------------------------------------------------------*/
-
-static GHashTable*
-kolab_settings_handler_create_table (KolabSettingsHandlerTblID tbl_id)
-{
-	/* g_assert (tbl_id < KOLAB_SETTINGS_HANDLER_TBL_LAST_ID); */
-
-	switch (tbl_id) {
-	case KOLAB_SETTINGS_HANDLER_TBL_SYNCSTRATEGY:
-		/* GINT_TO_POINTER() values (don't free()) */
-		return g_hash_table_new_full (g_str_hash,
-		                              g_str_equal,
-		                              g_free,
-		                              NULL);
-	case KOLAB_SETTINGS_HANDLER_TBL_FOLDERCREATE:
-		/* values are pointers to keys, don't free() */
-		return g_hash_table_new_full (g_str_hash,
-		                              g_str_equal,
-		                              g_free,
-		                              NULL);
-	default:
-		g_assert_not_reached ();
-	}
-}
-
-/**
- * kolab_settings_handler_set_value:
- * @self: a #KolabSettingsHandler instance
- * @tbl_id: ID for the internal table to store the @value in
- * @key: the key string to reference the value with
- * @value: a pointer to the data object to store
- * @err: a #GError object (or NULL)
- *
- * Store a @value under the given @key in an internal table identified
- * by @tbl_id. Be sure that the data pointed to does not get erased as long
- * as it is accessible via @tbl_id:@key.
- *
- * The data type @value points to is determined by the @tbl_id. Each table
- * has a certain value data type associated with it (see #KolabSettingsHandlerTblID),
- * so be sure to supply only pointers to the data type this table is meant
- * for (orelse, table destruction or replacing of existing values will fail
- * miserably).
- *
- * Returns: TRUE on success,
- *          FALSE otherwise (with @err set)
- */
-gboolean
-kolab_settings_handler_set_value (KolabSettingsHandler *self,
-                                  KolabSettingsHandlerTblID tbl_id,
-                                  const gchar *key,
-                                  gpointer value,
-                                  GError **err)
-{
-	KolabSettingsHandlerPrivate *priv = NULL;
-	GHashTable *tbl = NULL;
-
-	g_assert (KOLAB_IS_SETTINGS_HANDLER (self));
-	/* g_assert (tbl_id < KOLAB_SETTINGS_HANDLER_TBL_LAST_ID); */
-	g_assert (key != NULL);
-	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
-
-	priv = KOLAB_SETTINGS_HANDLER_PRIVATE (self);
-
-	g_assert (priv->is_configured == TRUE);
-	g_assert (priv->is_up == TRUE);
-
-	if (priv->sdata_tbl == NULL)
-		priv->sdata_tbl = g_hash_table_new_full (g_direct_hash,
-		                                         g_direct_equal,
-		                                         NULL,
-		                                         kolab_util_glib_ghashtable_gdestroy);
-	tbl = g_hash_table_lookup (priv->sdata_tbl,
-	                           GINT_TO_POINTER (tbl_id));
-	if (tbl == NULL) {
-		tbl = kolab_settings_handler_create_table (tbl_id);
-		g_hash_table_insert (priv->sdata_tbl,
-		                     GINT_TO_POINTER (tbl_id),
-		                     tbl);
-	}
-
-	g_hash_table_replace (tbl, g_strdup (key), value);
-	return TRUE;
-}
-
-/**
- * kolab_settings_handler_get_value:
- * @self: a #KolabSettingsHandler instance
- * @tbl_id: ID for the internal table to store the @value in
- * @key: the key string to reference the value with
- * @err: a #GError object (or NULL)
- *
- * Retrieve a @value under the given @key from an internal table identified
- * by @tbl_id.
- *
- * The data type @value points to is determined by the @tbl_id. Each table
- * has a certain value data type associated with it (see #KolabSettingsHandlerTblID).
- *
- * It is an error to try to retrieve a value if nothing has ever been stored
- * in any table or if a @tbl_id is given for a table into which nothing has
- * been stored before, or if there is no value stored for @key in @tbl_id
- * (@err has an error value set to #KOLAB_BACKEND_ERROR_NOTFOUND in these cases).
- *
- * Returns: a pointer to the data referenced by @tbl_id:@key on success,
- *	    NULL with @err set on failure or if not found
- */
-gconstpointer
-kolab_settings_handler_get_value (KolabSettingsHandler *self,
-                                  KolabSettingsHandlerTblID tbl_id,
-                                  const gchar *key,
-                                  GError **err)
-{
-	KolabSettingsHandlerPrivate *priv = NULL;
-	GHashTable *tbl = NULL;
-	gpointer value = NULL;
-	gpointer orig_key = NULL;
-	gboolean found = FALSE;
-
-	g_assert (KOLAB_IS_SETTINGS_HANDLER (self));
-	/* g_assert (tbl_id < KOLAB_SETTINGS_HANDLER_TBL_LAST_ID); */
-	g_assert (key != NULL);
-	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
-
-	priv = KOLAB_SETTINGS_HANDLER_PRIVATE (self);
-
-	g_assert (priv->is_configured == TRUE);
-	g_assert (priv->is_up == TRUE);
-
-	if (priv->sdata_tbl == NULL) {
-		g_set_error (err,
-		             KOLAB_BACKEND_ERROR,
-		             KOLAB_BACKEND_ERROR_NOTFOUND,
-		             _("Internal inconsistency detected: No settings table exists, no value has previously been set"));
-		return NULL;
-	}
-
-	tbl = g_hash_table_lookup (priv->sdata_tbl,
-	                           GINT_TO_POINTER (tbl_id));
-	if (tbl == NULL) {
-		g_set_error (err,
-		             KOLAB_BACKEND_ERROR,
-		             KOLAB_BACKEND_ERROR_NOTFOUND,
-		             _("Internal inconsistency detected: No settings table with ID '%i' exists"),
-		             tbl_id);
-		return NULL;
-	}
-
-	found = g_hash_table_lookup_extended (tbl, key, &orig_key, &value);
-	if (! found) {
-		g_set_error (err,
-		             KOLAB_BACKEND_ERROR,
-		             KOLAB_BACKEND_ERROR_NOTFOUND,
-		             _("Internal inconsistency detected: No settings value for table ID '%i', key ID '%s', exists"),
-		             tbl_id, key);
-		return NULL;
-	}
-
-	return value; /* may be NULL */
-}
-
-/*----------------------------------------------------------------------------*/
