@@ -170,9 +170,8 @@ conv_incidence_e_to_i (const ECalComponentWithTZ *ectz, I_incidence *i_incidence
 						if (g_str_has_prefix(value, "MAILTO:"))/* increase pointer by 7 to cut off prefix */
 							value +=7;
 
-						alarm->email_param->addresses = g_list_append(
-								alarm->email_param->addresses,
-								g_string_new(value));
+						alarm->email_param->addresses = g_list_append(alarm->email_param->addresses,
+						                                              g_string_new(value));
 					}
 
 					generic_g_slist_free(&attendee_list, free_attendee);
@@ -185,8 +184,7 @@ conv_incidence_e_to_i (const ECalComponentWithTZ *ectz, I_incidence *i_incidence
 					alarm->start_offset = (icaldurationtype_as_int(trigger->u.rel_duration)/60); /* (/60) as_int returns seconds, but kolab saved minutes */
 				if (trigger->type == E_CAL_COMPONENT_ALARM_TRIGGER_RELATIVE_END)
 					alarm->end_offset = (icaldurationtype_as_int(trigger->u.rel_duration)/60); /* (/60) as_int returns seconds, but kolab saved minutes */
-				if (trigger->type == E_CAL_COMPONENT_ALARM_TRIGGER_ABSOLUTE)
-				{
+				if (trigger->type == E_CAL_COMPONENT_ALARM_TRIGGER_ABSOLUTE) {
 					/* TODO: Maybe calculate a relative trigger from incidence->startdate and evolution absolute trigger->u.abs_time -abs_time is icaltimetype, calculate in minutes?
 					 *       XXX: Not tested! & Both, Evolution and Kontact do not provide absolute alarm trigger. Just iCal secifies it.
 					 *       convert icaltimetype to date_time/time_t for use with time.h
@@ -197,15 +195,13 @@ conv_incidence_e_to_i (const ECalComponentWithTZ *ectz, I_incidence *i_incidence
 					i_cal_time_type_to_date_or_datetime(&trigger->u.abs_time, evo_date_time);
 					evo_abs_time = evo_date_time->date_time;
 
-					if (incidence->startDate->date_time != NULL)
-					{
+					if (incidence->startDate->date_time != NULL) {
 						/* calculate difference in seconds with difftime when startDate is already date_time/time_t */
 						time_t *i_start_time = incidence->startDate->date_time;
 						double diff = 0.0;
 						diff = difftime(*evo_abs_time, *i_start_time);	/* returns seconds? */
 					}
-					else if (incidence->startDate->date != NULL)
-					{
+					else if (incidence->startDate->date != NULL) {
 						/* convert startDate from GDate to date_time/time_t and then calculate difference */
 						struct tm *stm = NULL;
 
@@ -285,16 +281,16 @@ static Alarm_type
 alarm_type_e_to_i (ECalComponentAlarmAction action)
 {
 	switch (action) {
-		case E_CAL_COMPONENT_ALARM_AUDIO:
-			return I_ALARM_TYPE_AUDIO;
-		case E_CAL_COMPONENT_ALARM_DISPLAY:
-			return I_ALARM_TYPE_DISPLAY;
-		case E_CAL_COMPONENT_ALARM_EMAIL:
-			return I_ALARM_TYPE_EMAIL;
-		case E_CAL_COMPONENT_ALARM_PROCEDURE:
-			return I_ALARM_TYPE_PROCEDURE;
-		default:
-			return I_ALARM_TYPE_DISPLAY;
+	case E_CAL_COMPONENT_ALARM_AUDIO:
+		return I_ALARM_TYPE_AUDIO;
+	case E_CAL_COMPONENT_ALARM_DISPLAY:
+		return I_ALARM_TYPE_DISPLAY;
+	case E_CAL_COMPONENT_ALARM_EMAIL:
+		return I_ALARM_TYPE_EMAIL;
+	case E_CAL_COMPONENT_ALARM_PROCEDURE:
+		return I_ALARM_TYPE_PROCEDURE;
+	default:
+		return I_ALARM_TYPE_DISPLAY;
 	}
 }
 
@@ -306,18 +302,18 @@ static Incidence_status
 incidence_status_e_to_i (icalparameter_partstat ical_part_status)
 {
 	switch (ical_part_status) {
-		case ICAL_PARTSTAT_NEEDSACTION:
-			return I_INC_STATUS_NONE;
-		case ICAL_PARTSTAT_TENTATIVE:
-			return I_INC_STATUS_TENTATIVE;
-		case ICAL_PARTSTAT_ACCEPTED:
-			return I_INC_STATUS_ACCEPTED;
-		case ICAL_PARTSTAT_DECLINED:
-			return I_INC_STATUS_DECLINED;
-		case ICAL_PARTSTAT_DELEGATED:
-			return I_INC_STATUS_DELEGATED;
-		default:
-			return I_INC_STATUS_NONE;
+	case ICAL_PARTSTAT_NEEDSACTION:
+		return I_INC_STATUS_NONE;
+	case ICAL_PARTSTAT_TENTATIVE:
+		return I_INC_STATUS_TENTATIVE;
+	case ICAL_PARTSTAT_ACCEPTED:
+		return I_INC_STATUS_ACCEPTED;
+	case ICAL_PARTSTAT_DECLINED:
+		return I_INC_STATUS_DECLINED;
+	case ICAL_PARTSTAT_DELEGATED:
+		return I_INC_STATUS_DELEGATED;
+	default:
+		return I_INC_STATUS_NONE;
 	}
 }
 
@@ -328,16 +324,16 @@ static Incidence_cutype
 incidence_cutype_e_to_i (icalparameter_cutype ical_part_type)
 {
 	switch (ical_part_type) {
-		case ICAL_CUTYPE_INDIVIDUAL:
-			return I_INC_CUTYPE_INDIVIDUAL;
-		case ICAL_CUTYPE_GROUP:
-			return I_INC_CUTYPE_GROUP;
-		case ICAL_CUTYPE_RESOURCE:
-			return I_INC_CUTYPE_RESOURCE;
-		case ICAL_CUTYPE_ROOM:
-			return I_INC_CUTYPE_ROOM;
-		default:
-			return I_INC_CUTYPE_UNDEFINED;
+	case ICAL_CUTYPE_INDIVIDUAL:
+		return I_INC_CUTYPE_INDIVIDUAL;
+	case ICAL_CUTYPE_GROUP:
+		return I_INC_CUTYPE_GROUP;
+	case ICAL_CUTYPE_RESOURCE:
+		return I_INC_CUTYPE_RESOURCE;
+	case ICAL_CUTYPE_ROOM:
+		return I_INC_CUTYPE_ROOM;
+	default:
+		return I_INC_CUTYPE_UNDEFINED;
 	}
 }
 
@@ -348,16 +344,16 @@ static Incidence_role
 incidence_role_e_to_i (icalparameter_role ical_role)
 {
 	switch (ical_role) {
-		case ICAL_ROLE_REQPARTICIPANT:
-			return I_INC_ROLE_REQUIRED;
-		case ICAL_ROLE_OPTPARTICIPANT:
-			return I_INC_ROLE_OPTIONAL;
-		case ICAL_ROLE_NONPARTICIPANT:
-			return I_INC_ROLE_RESOURCE;
-		case ICAL_ROLE_CHAIR:
-			return I_INC_ROLE_REQUIRED;
-		default:
-			return I_INC_ROLE_REQUIRED;
+	case ICAL_ROLE_REQPARTICIPANT:
+		return I_INC_ROLE_REQUIRED;
+	case ICAL_ROLE_OPTPARTICIPANT:
+		return I_INC_ROLE_OPTIONAL;
+	case ICAL_ROLE_NONPARTICIPANT:
+		return I_INC_ROLE_RESOURCE;
+	case ICAL_ROLE_CHAIR:
+		return I_INC_ROLE_REQUIRED;
+	default:
+		return I_INC_ROLE_REQUIRED;
 	}
 }
 
@@ -376,25 +372,25 @@ static Week_day
 recurrence_weekday_e_to_i (icalrecurrencetype_weekday weekday)
 {
 	switch (weekday) {
-		case ICAL_NO_WEEKDAY:
-			return 0;
-		case ICAL_MONDAY_WEEKDAY:
-			return I_COMMON_MONDAY;
-		case ICAL_TUESDAY_WEEKDAY:
-			return I_COMMON_TUESDAY;
-		case ICAL_WEDNESDAY_WEEKDAY:
-			return I_COMMON_WEDNESDAY;
-		case ICAL_THURSDAY_WEEKDAY:
-			return I_COMMON_THURSDAY;
-		case ICAL_FRIDAY_WEEKDAY:
-			return I_COMMON_FRIDAY;
-		case ICAL_SATURDAY_WEEKDAY:
-			return I_COMMON_SATURDAY;
-		case ICAL_SUNDAY_WEEKDAY:
-			return I_COMMON_SUNDAY;
-		default:
-			log_warn("invalid weekday enumeration value: %d", weekday);
-			return 0;
+	case ICAL_NO_WEEKDAY:
+		return 0;
+	case ICAL_MONDAY_WEEKDAY:
+		return I_COMMON_MONDAY;
+	case ICAL_TUESDAY_WEEKDAY:
+		return I_COMMON_TUESDAY;
+	case ICAL_WEDNESDAY_WEEKDAY:
+		return I_COMMON_WEDNESDAY;
+	case ICAL_THURSDAY_WEEKDAY:
+		return I_COMMON_THURSDAY;
+	case ICAL_FRIDAY_WEEKDAY:
+		return I_COMMON_FRIDAY;
+	case ICAL_SATURDAY_WEEKDAY:
+		return I_COMMON_SATURDAY;
+	case ICAL_SUNDAY_WEEKDAY:
+		return I_COMMON_SUNDAY;
+	default:
+		log_warn("invalid weekday enumeration value: %d", weekday);
+		return 0;
 	}
 }
 
@@ -441,10 +437,9 @@ recurrence_e_to_i (const ECalComponentWithTZ *ectz, I_incidence *i_incidence)
 	while (exdate_list) {
 		ECalComponentDateTime *e_cal_date_time = (ECalComponentDateTime *) exdate_list->data;
 
-		GDate *exclusion_date = g_date_new_dmy(
-				(GDateDay) e_cal_date_time->value->day,
-				(GDateMonth) e_cal_date_time->value->month,
-				(GDateYear)e_cal_date_time->value->year);
+		GDate *exclusion_date = g_date_new_dmy((GDateDay) e_cal_date_time->value->day,
+		                                       (GDateMonth) e_cal_date_time->value->month,
+		                                       (GDateYear)e_cal_date_time->value->year);
 		i_incidence->recurrence->exclusion = g_list_append( i_incidence->recurrence->exclusion, (GDate *) exclusion_date);
 
 		exdate_list = exdate_list->next;
@@ -467,10 +462,10 @@ recurrence_e_to_i (const ECalComponentWithTZ *ectz, I_incidence *i_incidence)
 
 		/* remapping of missing I_REC_CYCLE_YEARLY_WEEKDAY support in evolution */
 		if (rec_type->freq == ICAL_MONTHLY_RECURRENCE
-				&& rec_type->by_day[0] != ICAL_RECURRENCE_ARRAY_MAX
-				&& rec_type->by_set_pos[0] != ICAL_RECURRENCE_ARRAY_MAX
-				&& rec_type->by_set_pos[1] == ICAL_RECURRENCE_ARRAY_MAX
-				&& i_incidence->recurrence->interval == 12) {
+		    && rec_type->by_day[0] != ICAL_RECURRENCE_ARRAY_MAX
+		    && rec_type->by_set_pos[0] != ICAL_RECURRENCE_ARRAY_MAX
+		    && rec_type->by_set_pos[1] == ICAL_RECURRENCE_ARRAY_MAX
+		    && i_incidence->recurrence->interval == 12) {
 			gint month = 0;
 
 			i_incidence->recurrence->recurrence_cycle = I_REC_CYCLE_YEARLY_WEEKDAY;
@@ -603,10 +598,9 @@ static void
 recurrence_set_range(struct icalrecurrencetype *rec_type, Recurrence *recurrence)
 {
 	if (icaltime_is_date (rec_type->until) == TRUE) {
-		recurrence->range_date = g_date_new_dmy(
-			(GDateDay) rec_type->until.day,
-			(GDateMonth) rec_type->until.month,
-			(GDateYear) rec_type->until.year);
+		recurrence->range_date = g_date_new_dmy((GDateDay) rec_type->until.day,
+		                                        (GDateMonth) rec_type->until.month,
+		                                        (GDateYear) rec_type->until.year);
 	} else if (rec_type->count > 0) {
 		recurrence->range_number = g_new0(gint, 1);
 		*recurrence->range_number = rec_type->count;
@@ -614,4 +608,3 @@ recurrence_set_range(struct icalrecurrencetype *rec_type, Recurrence *recurrence
 		/* infinite recurrence */
 	}
 }
-
