@@ -31,6 +31,8 @@
 /*----------------------------------------------------------------------------*/
 
 #include <glib.h>
+#include <gio/gio.h>
+
 #include "camel-system-headers.h"
 
 /*----------------------------------------------------------------------------*/
@@ -95,6 +97,11 @@ KolabUtilCamelIMAPPath*
 kolab_util_camel_imap_path_split (const gchar *full_path,
                                   const gchar *delim);
 
+gboolean
+kolab_util_camel_imapx_stream_eos (CamelIMAPXStream *is,
+                                   GCancellable *cancellable,
+                                   GError **err);
+
 /*----------------------------------------------------------------------------*/
 
 #endif /* _KOLAB_UTIL_CAMEL_H_ */
