@@ -66,13 +66,13 @@ typedef enum {
  * TODO check whether this annotation info is needed
  *      (used for events, tasks)
  *
-typedef enum {
-	KOLAB_INCIDENCES_FOR_INVAL	= 0,
-	KOLAB_INCIDENCES_FOR_NOBODY	= 1 << 0,
-	KOLAB_INCIDENCES_FOR_ADMINS	= 1 << 1,
-	KOLAB_INCIDENCES_FOR_READERS	= 1 << 2
-} KolabFolderMetaIncidencesForID;
- */
+ typedef enum {
+ KOLAB_INCIDENCES_FOR_INVAL	= 0,
+ KOLAB_INCIDENCES_FOR_NOBODY	= 1 << 0,
+ KOLAB_INCIDENCES_FOR_ADMINS	= 1 << 1,
+ KOLAB_INCIDENCES_FOR_READERS	= 1 << 2
+ } KolabFolderMetaIncidencesForID;
+*/
 
 /* IMAP folder annotation: /vendor/kolab/pxfb-readable-for
  * TODO do we need to care for the (p)xfb annotation locally?
@@ -93,6 +93,16 @@ typedef enum {
 	KOLAB_FOLDER_LAST_CONTEXT
 } KolabFolderContextID;
 
+/* IMAP ACL folder permissions types */
+typedef enum {
+	KOLAB_FOLDER_PERM_NOCHANGE = 0,
+	KOLAB_FOLDER_PERM_READ,
+	KOLAB_FOLDER_PERM_APPEND,
+	KOLAB_FOLDER_PERM_WRITE,
+	KOLAB_FOLDER_PERM_ALL,
+	KOLAB_FOLDER_LAST_PERM
+} KolabFolderPermID;
+
 typedef struct _KolabFolderDescriptor KolabFolderDescriptor;
 struct _KolabFolderDescriptor {
 	gchar *name;
@@ -113,7 +123,11 @@ KolabFolderContextID
 kolab_util_folder_type_map_to_context_id (KolabFolderTypeID type_id);
 
 gboolean
-kolab_util_folder_type_match_with_context_id (KolabFolderTypeID type_id, KolabFolderContextID context_id);
+kolab_util_folder_type_match_with_context_id (KolabFolderTypeID type_id,
+                                              KolabFolderContextID context_id);
+
+const gchar*
+kolab_util_folder_perm_get_string (KolabFolderPermID perm_id);
 
 KolabFolderDescriptor*
 kolab_util_folder_descriptor_new (const gchar *foldername,
