@@ -78,7 +78,7 @@ typedef struct _KolabUtilHttpJob {
 	gchar *pkcs11pin;
 } KolabUtilHttpJob;
 
-void kolab_util_http_init (void);
+void kolab_util_http_init (const gchar *user_home);
 void kolab_util_http_shutdown (void);
 
 KolabUtilHttpJob* kolab_util_http_job_new (void);
