@@ -68,7 +68,8 @@ test_kolab_util_http (void)
 
 	/* init subsystems */
 	kolab_util_glib_init ();
-	kolab_util_http_init ();
+	kolab_util_http_init (g_get_home_dir ());
+
 	/* libcamel
 	 *
 	 * Curl init may configure the underlying SSL lib,
